@@ -38,9 +38,14 @@ async def start_server(server: Server, gateway: bool = True):
   logging.info('starting grpc server...')
   await server.start()
   logging.info('started grpc server on port 8080')
-  if gateway:
-    loop = asyncio.get_event_loop()
-    loop.add_signal_handler(signal.SIGTERM, _signal_handler)
-    await start_gateway(server.__dict__['descriptor'], shutdown_trigger=shutdown_event.wait)
-  else:
-    await server.wait_for_termination()
\ No newline at end of file
+  try:
+    if gateway:
+      loop = asyncio.get_event_loop()
+      loop.add_signal_handler(signal.SIGTERM, _signal_handler)
+      await start_gateway(server.__dict__['descriptor'], shutdown_trigger=shutdown_event.wait)
+      loop.create_task(start_server(server))
+      loop.run_forever()
+    else:
+      await server.wait_for_termination()
+  except KeyboardInterrupt:
+    logging.info('stopped server (keyboard interrupt)')
